@@ -78,7 +78,7 @@ def get_file(path, *args, aws_key=None, aws_secret=None, **kwargs):
         except Exception:
             pass
     else:
-        fp = open(path, *args, **op_kwargs)
+        fp = open(path, *args, **kwargs)
 
     return fp
 
@@ -101,20 +101,25 @@ def download_file(path, dest=None, aws_key=None, aws_secret=None, **kwargs):
                 break
 
 
-def upload_file(path, dest, aws_key=None, aws_secret=None, **kwargs):
+def upload_file_obj(robj, dest, aws_key=None, aws_secret=None, **kwargs):
     assert dest.startswith(_S3_ATTRIBUTE), f"Not a s3 source: {dest}"
-    if dest.endswith("/"):
-        dest = dest + basename(path)
-    with open(path, "rb") as r, get_file(dest, "wb", aws_key=aws_key, aws_secret=aws_secret, **kwargs) as w:
+    with get_file(dest, "wb", aws_key=aws_key, aws_secret=aws_secret, **kwargs) as w:
         total = 0
         while True:
-            size = w.write(r.read(UPLOAD_CHUNK_SIZE))
+            size = w.write(robj.read(UPLOAD_CHUNK_SIZE))
             total += size
             logger.info(f"Uploaded {total} bytes to {dest}")
             if size < UPLOAD_CHUNK_SIZE:
                 break
 
 
+def upload_file(path, dest, aws_key=None, aws_secret=None, **kwargs):
+    if dest.endswith("/"):
+        dest = dest + basename(path)
+    with open(path, "rb") as r:
+        upload_file_obj(r, dest, aws_key, aws_secret, **kwargs)
+
+
 def get_glob(path, aws_key=None, aws_secret=None, **kwargs):
     if path.startswith(_S3_ATTRIBUTE):
         fs = S3FileSystem(**s3_credentials(aws_key, aws_secret), **kwargs)
@@ -136,9 +141,8 @@ def cp_file(src_path, dest_path, aws_key=None, aws_secret=None, **kwargs):
 
 def mv_file(src_path, dest_path, aws_key=None, aws_secret=None, **kwargs):
     if src_path.startswith(_S3_ATTRIBUTE) and dest_path.startswith(_S3_ATTRIBUTE):
-        op_kwargs = kwargs.pop("op_kwargs", {})
-        fs = S3FileSystem(**s3_credentials(aws_key, aws_secret), **kwargs)
-        fs.mv(s3_path(src_path), s3_path(dest_path), **op_kwargs)
+        cp_file(src_path, dest_path, aws_key, aws_secret, **kwargs)
+        rm_file(src_path, aws_key, aws_secret, **kwargs)
     elif src_path.startswith(_S3_ATTRIBUTE):
         download_file(src_path, dest_path, aws_key, aws_secret, **kwargs)
         rm_file(src_path)
@@ -157,8 +161,9 @@ def mv_file(src_path, dest_path, aws_key=None, aws_secret=None, **kwargs):
 
 def rm_file(path, aws_key=None, aws_secret=None, **kwargs):
     if path.startswith(_S3_ATTRIBUTE):
+        op_kwargs = kwargs.pop("op_kwargs", {})
         fs = S3FileSystem(**s3_credentials(aws_key, aws_secret), **kwargs)
-        fs.rm(s3_path(path))
+        fs.rm(s3_path(path), **op_kwargs)
     else:
         remove(path)
 
@@ -168,7 +173,8 @@ def list_folder(path, aws_key=None, aws_secret=None, **kwargs) -> List[str]:
         fs = S3FileSystem(**s3_credentials(aws_key, aws_secret), **kwargs)
 
         try:
-            listing = [f"s3://{name}" for name in fs.ls(s3_path(path, is_folder=True))]
+            path = s3_path(path, is_folder=True)
+            listing = [f"s3://{name}" for name in fs.ls(path) if name != path]
         except FileNotFoundError:
             listing = []
 
@@ -262,6 +268,7 @@ class S3SessionFactory:
         self.credentials_expiration = None
         self.sts_client = boto3.client("sts", aws_access_key_id=aws_key, aws_secret_access_key=aws_secret)
         self.full_credentials = {}
+        self.s3_client = None
 
     def get_credentials(self):
         """
@@ -276,6 +283,11 @@ class S3SessionFactory:
                 RoleArn=self.aws_role, RoleSessionName=session_name, ExternalId=self.aws_external_id,
             )["Credentials"]
             self.credentials_expiration = self.full_credentials["Expiration"]
+            self.s3_client = boto3.session.Session(
+                aws_access_key_id=self.full_credentials["AccessKeyId"],
+                aws_secret_access_key=self.full_credentials["SecretAccessKey"],
+                aws_session_token=self.full_credentials["SessionToken"],
+            ).client("s3")
         return {
             "aws_key": self.full_credentials["AccessKeyId"],
             "aws_secret": self.full_credentials["SecretAccessKey"],
@@ -294,6 +306,7 @@ class S3Helper:
 
         for method in (
             get_file,
+            upload_file_obj,
             upload_file,
             download_file,
             list_folder,
